Struct CliOptionParser

pub struct CliOptionParser { /* private fields */ }
Struct to parse the option arguments Ignores invalid arguments passed

Implementations

Source

impl CliOptionParser

pub fn new(header: String, footer: String) -> CliOptionParser

Gives a new instance of CliOptionParser

pub fn parse(&mut self) -> Vec<String>

function to parse and then returns the normal arguments

pub fn is_enabled(&self, name: &str) -> bool

Checks if an option with the given name is present/enabled

pub fn get_option_values(&self, name: &str) -> &Vec<String>

if an option with the given name is enabled, returns the reference to value list else returns an empty list

pub fn register_option( &mut self, short_form: Option<String>, long_form: Option<String>, help_text: &str, name: &str, )

Registers an Option with the given short form, long form, help text with the name name the option can be accessed by using the name

pub fn help_text(&self) -> String

function to return help text when asked